#!/usr/bin/env python3
"""
Rename Files: Replace 'fourarms' with 'tetramand' in filenames

Usage:
1. Drag and drop files onto this script
2. The script will rename all files, replacing 'fourarms' with 'tetramand'
   in the filename (case insensitive)

Example:
    'my_fourarms_character.jpg' → 'my_tetramand_character.jpg'
    'FOURARMS_spec.txt' → 'tetramand_spec.txt'
"""

import os
import sys
import re

def rename_files(file_paths):
    """
    Rename files by replacing 'fourarms' with 'tetramand' in their filenames.
    
    Args:
        file_paths (list): List of file paths to process
    
    Returns:
        list: List of tuples containing (old_name, new_name, success_status)
    """
    results = []
    
    for file_path in file_paths:
        # Get directory and filename
        directory, filename = os.path.split(file_path)
        
        # Create new filename using regex for case-insensitive replacement
        new_filename = re.sub(r'ripjaws', 'piscciss_volann', filename, flags=re.IGNORECASE)
        
        # Skip if no change would be made
        if new_filename == filename:
            results.append((filename, filename, "SKIPPED (no match)"))
            continue
        
        # Create full paths
        new_path = os.path.join(directory, new_filename)
        
        # Check if destination already exists
        if os.path.exists(new_path) and file_path != new_path:
            results.append((filename, new_filename, "FAILED (destination exists)"))
            continue
        
        try:
            # Rename the file
            os.rename(file_path, new_path)
            results.append((filename, new_filename, "SUCCESS"))
        except Exception as e:
            results.append((filename, new_filename, f"FAILED ({str(e)})"))
    
    return results

def main():
    """Main function to process command line arguments."""
    if len(sys.argv) < 2:
        print("Error: No files provided.")
        print("Usage: Drag and drop files onto this script to rename them.")
        input("Press Enter to exit...")
        return
    
    files_to_process = sys.argv[1:]
    print(f"Processing {len(files_to_process)} files...")
    
    results = rename_files(files_to_process)
    
    # Display results
    print("\nRename Results:")
    print("-" * 80)
    print(f"{'ORIGINAL NAME':<30} {'NEW NAME':<30} {'STATUS':<20}")
    print("-" * 80)
    
    for old_name, new_name, status in results:
        # Truncate long filenames for display
        old_display = (old_name[:27] + "...") if len(old_name) > 30 else old_name
        new_display = (new_name[:27] + "...") if len(new_name) > 30 else new_name
        print(f"{old_display:<30} {new_display:<30} {status:<20}")
    
    print("-" * 80)
    successful = sum(1 for _, _, status in results if status.startswith("SUCCESS"))
    print(f"Renamed {successful} of {len(results)} files.")
    
    input("\nPress Enter to exit...")

if __name__ == "__main__":
    main()
